<template>
    <div class="search-panel">
        <el-form ref="form" :model="form" label-width="90px" class="search-form">
            <el-form-item label="企业名称：" size="mini" class="search-panel-item">
                <el-select style="width: 100%" v-model="form.eventName" @change="handlePipelineType"
                           :popper-class="'select-down'">
                    <el-option
                            v-for="item in form.eventNameList"
                            :key="item.code"
                            :label="item.name"
                            :value="item.name">
                    </el-option>
                </el-select>
            </el-form-item>
            <el-form-item label="资源环境：" size="mini" class="search-panel-item">
                <el-select style="width: 100%" v-model="form.pipelineType" @change="handlePipelineType"
                           :popper-class="'select-down'">
                    <el-option
                            v-for="item in items"
                            :key="item.code"
                            :label="item.name"
                            :value="item.name">
                    </el-option>
                </el-select>
            </el-form-item>
            <el-form-item :label="form.pipelineType+'：'" size="mini">
                <el-select style="width: 100%" v-model="form.dataType" value-key="code"
                           :popper-class="'select-down'" @change="handleDataType">
                    <el-option
                            v-for="item in subItems"
                            :key="item.code"
                            :label="item.name"
                            :value="item">
                    </el-option>
                </el-select>
            </el-form-item>
            <div class="rightButtonSearch">
                <el-input v-model="form.keyword" size="mini" placeholder="在此输入关键字搜索"></el-input>
                <el-button class="el-icon-search" @click="handleSearch"></el-button>
            </div>
        </el-form>
        <el-scrollbar style="height:286.22px">
            <div class="environmental-risk-list" v-for="(item,index) in list" :key="index"
                 :class="activeNum===index?'hover':''" @click="handleLocation(item,index)">
                <!--   <i class="state"></i>-->
                <img class="state" :src="getImgSrc()" style="background: none"/>
                <h3>事件名称:XXX事件</h3>
                <h5>事件事件:2021年3月21日</h5>
                <p>事件状态：<span>审批阶段</span></p>
                <p>事件类型：<span>真实事件</span></p>
            </div>
        </el-scrollbar>
    </div>
</template>

<script>
// import { LayerEntEmer } from '../../../../../conf/layers/LayerEntEmer'
import WfsHelper from '@components/helpers/WfsHelper'
import AjaxUtils from '@utils/AjaxUtils'

export default {
  name: 'ResourcesQuery',
  data () {
    return {
      form: {
        eventName: '',
        pipelineType: '资源类型',
        dataType: '',
        keyword: '',
        eventNameList: [
          { name: '金陵石化' },
          { name: '南京化学' }
        ]
      },
      activeNum: -1,
      list: [],
      // items: [LayerEntEmer],
      items: [],
      // subItems: LayerEntEmer.layers,
      subItems: [],
      WfsHelper: null
    }
  },
  mounted () {
    this.wfsHelper = new WfsHelper()
  },
  methods: {
    getImgSrc () {
      const icon = this.form.dataType.icon
      return icon ? 'assets/images/map/' + icon : ''
    },
    handlePipelineType () {
      console.log('item')
    },
    handleDataType () {
      console.log('item')
    },
    async handleSearch () {
      this.list = []
      this.wfsHelper.clearFilter()
      // todo 现在企业应急还没区分开类型，后面改
      // this.wfsHelper.setTypeName([this.form.dataType.typeName])
      this.wfsHelper.setTypeName(['sewer:emergency'])
      if (this.form.keyword) {
        this.wfsHelper.addLike('name', this.form.keyword)
      }
      const res = await AjaxUtils.GetDataAsynByUrl(this.wfsHelper.getUrl(), {})
      if (res instanceof Object && Object.prototype.hasOwnProperty.call(res, 'features')) {
        this.list = res.features
      }
    },
    handleLocation (val, index) {
      console.log(val)
      this.activeNum = index
      // layer && layer.openPopup()
      // window.layerFactory.flyByFeature(val, this.form.dataType.code)
      window.map.flyTo([val.properties.y, val.properties.x], 15)
    }
  }
}
</script>

<style scoped>

</style>
